"""
Django SEO Optimizer - A powerful SEO optimization package
Created by avixiii (https://avixiii.com)
"""
from .version import VERSION

__version__ = VERSION
__author__ = "avixiii"
__email__ = "contact@avixiii.com"
__website__ = "https://avixiii.com"

default_app_config = 'seo_optimizer.apps.SEOOptimizerConfig'
